pub struct ConversationEpochsOlderThan { /* private fields */ }Expand description
Some data, e.g., TntSecrets, need to be cleaned up if they belong to a
conversation epoch that is older than a given epoch. To enable this, SearchableEntity is implemented with this
search key.
Implementations
Sourceimpl ConversationEpochsOlderThan
impl ConversationEpochsOlderThan
pub const fn new( conversation_id: ConversationId, epoch: u64, ) -> ConversationEpochsOlderThan