pub struct ConnectionGuard<'a> { /* private fields */ }Expand description
Exclusive access to the database connection
Note that this is only ever constructed when we already hold exclusive access, and the connection has already been tested to ensure that it is non-empty.
Methods from Deref<Target = KeystoreDatabaseConnection>
pub async fn conn(&self) -> MutexGuard<'_, Connection>
Sourcepub async fn export_copy(
&self,
destination_path: &str,
) -> CryptoKeystoreResult<()>
pub async fn export_copy( &self, destination_path: &str, ) -> CryptoKeystoreResult<()>
Export a copy of the database to the specified path using VACUUM INTO.
This creates a fully vacuumed and optimized copy of the database. The copy will be encrypted with the same key as the source database.
Arguments
destination_path- The file path where the database copy should be created
Errors
Returns an error if:
- The database is in-memory (cannot export in-memory databases)
- The destination path is invalid
- The VACUUM INTO operation fails