pub struct E2eiIntermediateCert {
pub ski_aki_pair: String,
pub content: Vec<u8>,
}Fields
ski_aki_pair: Stringcontent: Vec<u8>Trait Implementations
Sourceimpl BorrowPrimaryKey for E2eiIntermediateCert
impl BorrowPrimaryKey for E2eiIntermediateCert
type BorrowedPrimaryKey = str
Sourcefn borrow_primary_key(&self) -> &Self::BorrowedPrimaryKey
fn borrow_primary_key(&self) -> &Self::BorrowedPrimaryKey
Borrow this entity’s primary key without copying any data. Read more
Sourceimpl Clone for E2eiIntermediateCert
impl Clone for E2eiIntermediateCert
Sourcefn clone(&self) -> E2eiIntermediateCert
fn clone(&self) -> E2eiIntermediateCert
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for E2eiIntermediateCert
impl Debug for E2eiIntermediateCert
Sourceimpl<'de> Deserialize<'de> for E2eiIntermediateCert
impl<'de> Deserialize<'de> for E2eiIntermediateCert
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for E2eiIntermediateCert
impl Entity for E2eiIntermediateCert
Sourceconst COLLECTION_NAME: &'static str = "e2ei_intermediate_certs"
const COLLECTION_NAME: &'static str = "e2ei_intermediate_certs"
The table name for this entity
Sourcefn get(
conn: &Connection,
key: &Self::PrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>
fn get( conn: &Connection, key: &Self::PrimaryKey, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for E2eiIntermediateCert
impl EntityDatabaseMutation for E2eiIntermediateCert
Sourcetype AutoGeneratedFields = ()
type AutoGeneratedFields = ()
The
pre_save method might generate or update some fields of the item. The canonical example is an updated_at
field. Read moreSourcefn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
fn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
Use the transaction’s interface to save this entity to the database
Sourcefn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
fn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
Use the transaction’s interface to count the number of entities of this type in the database.
Sourcefn delete(
tx: &Transaction<'_>,
id: &Self::PrimaryKey,
) -> CryptoKeystoreResult<bool>
fn delete( tx: &Transaction<'_>, id: &Self::PrimaryKey, ) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourcefn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
fn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
Adjust self before saving. Read more
Sourceimpl EntityDeleteBorrowed for E2eiIntermediateCert
impl EntityDeleteBorrowed for E2eiIntermediateCert
Sourcefn delete_borrowed(
tx: &Transaction<'_>,
id: &<Self as BorrowPrimaryKey>::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<bool>
fn delete_borrowed( tx: &Transaction<'_>, id: &<Self as BorrowPrimaryKey>::BorrowedPrimaryKey, ) -> CryptoKeystoreResult<bool>
Delete an entity by a borrowed form of its primary key.
Sourceimpl EntityGetBorrowed for E2eiIntermediateCert
impl EntityGetBorrowed for E2eiIntermediateCert
Sourcefn get_borrowed(
conn: &Connection,
key: &Self::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>where
for<'pk> &'pk Self::BorrowedPrimaryKey: KeyType,
fn get_borrowed(
conn: &Connection,
key: &Self::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>where
for<'pk> &'pk Self::BorrowedPrimaryKey: KeyType,
Get an entity by a borrowed form of its primary key.
Sourceimpl PartialEq for E2eiIntermediateCert
impl PartialEq for E2eiIntermediateCert
Sourcefn eq(&self, other: &E2eiIntermediateCert) -> bool
fn eq(&self, other: &E2eiIntermediateCert) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PrimaryKey for E2eiIntermediateCert
impl PrimaryKey for E2eiIntermediateCert
Sourcetype PrimaryKey = String
type PrimaryKey = String
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl Serialize for E2eiIntermediateCert
impl Serialize for E2eiIntermediateCert
Sourceimpl ToValue for E2eiIntermediateCert
impl ToValue for E2eiIntermediateCert
Sourceimpl Zeroize for E2eiIntermediateCert
impl Zeroize for E2eiIntermediateCert
impl Eq for E2eiIntermediateCert
impl StructuralPartialEq for E2eiIntermediateCert