pub struct ProteusSession {
pub id: String,
pub session: Vec<u8>,
}Fields
id: Stringsession: Vec<u8>Trait Implementations
Sourceimpl BorrowPrimaryKey for ProteusSession
impl BorrowPrimaryKey for ProteusSession
type BorrowedPrimaryKey = str
Sourcefn borrow_primary_key(&self) -> &Self::BorrowedPrimaryKey
fn borrow_primary_key(&self) -> &Self::BorrowedPrimaryKey
Borrow this entity’s primary key without copying any data. Read more
Sourceimpl Clone for ProteusSession
impl Clone for ProteusSession
Sourcefn clone(&self) -> ProteusSession
fn clone(&self) -> ProteusSession
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProteusSession
impl Debug for ProteusSession
Sourceimpl<'de> Deserialize<'de> for ProteusSession
impl<'de> Deserialize<'de> for ProteusSession
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for ProteusSession
impl Entity for ProteusSession
Sourceconst COLLECTION_NAME: &'static str = "proteus_sessions"
const COLLECTION_NAME: &'static str = "proteus_sessions"
The table name for this entity
Sourcefn get(
conn: &Connection,
key: &Self::PrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>
fn get( conn: &Connection, key: &Self::PrimaryKey, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for ProteusSession
impl EntityDatabaseMutation for ProteusSession
Sourcetype AutoGeneratedFields = ()
type AutoGeneratedFields = ()
The
pre_save method might generate or update some fields of the item. The canonical example is an updated_at
field. Read moreSourcefn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
fn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
Use the transaction’s interface to save this entity to the database
Sourcefn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
fn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
Use the transaction’s interface to count the number of entities of this type in the database.
Sourcefn delete(
tx: &Transaction<'_>,
id: &Self::PrimaryKey,
) -> CryptoKeystoreResult<bool>
fn delete( tx: &Transaction<'_>, id: &Self::PrimaryKey, ) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourcefn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
fn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
Adjust self before saving. Read more
Sourceimpl EntityDeleteBorrowed for ProteusSession
impl EntityDeleteBorrowed for ProteusSession
Sourcefn delete_borrowed(
tx: &Transaction<'_>,
id: &<Self as BorrowPrimaryKey>::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<bool>
fn delete_borrowed( tx: &Transaction<'_>, id: &<Self as BorrowPrimaryKey>::BorrowedPrimaryKey, ) -> CryptoKeystoreResult<bool>
Delete an entity by a borrowed form of its primary key.
Sourceimpl EntityGetBorrowed for ProteusSession
impl EntityGetBorrowed for ProteusSession
Sourcefn get_borrowed(
conn: &Connection,
key: &Self::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>where
for<'pk> &'pk Self::BorrowedPrimaryKey: KeyType,
fn get_borrowed(
conn: &Connection,
key: &Self::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>where
for<'pk> &'pk Self::BorrowedPrimaryKey: KeyType,
Get an entity by a borrowed form of its primary key.
Sourceimpl PartialEq for ProteusSession
impl PartialEq for ProteusSession
Sourcefn eq(&self, other: &ProteusSession) -> bool
fn eq(&self, other: &ProteusSession) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PrimaryKey for ProteusSession
impl PrimaryKey for ProteusSession
Sourcetype PrimaryKey = String
type PrimaryKey = String
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl Serialize for ProteusSession
impl Serialize for ProteusSession
Sourceimpl Zeroize for ProteusSession
impl Zeroize for ProteusSession
impl Eq for ProteusSession
impl StructuralPartialEq for ProteusSession