StoredBufferedCommit

Struct StoredBufferedCommit 

pub struct StoredBufferedCommit { /* private fields */ }
Entity representing a buffered commit.

There should always exist either 0 or 1 of these in the store per conversation. Commits are buffered if not all proposals they reference have yet been received.

We don’t automatically zeroize on drop because the commit data is still encrypted at this point; it is not risky to leave it in memory.

Implementations

Source

impl StoredBufferedCommit

pub fn new(conversation_id: Vec<u8>, commit_data: Vec<u8>) -> Self

Create a new Self from conversation id and the commit data.

pub fn conversation_id(&self) -> &[u8]

pub fn commit_data(&self) -> &[u8]

pub fn into_commit_data(self) -> Vec<u8>