pub struct StoredCredential {
pub session_id: Vec<u8>,
pub credential: Vec<u8>,
pub created_at: u64,
pub ciphersuite: u16,
pub public_key: Vec<u8>,
pub private_key: Vec<u8>,
}Expand description
Entity representing a persisted Credential
Fields
session_id: Vec<u8>Note: this is not a unique identifier, but the session id this credential belongs to.
credential: Vec<u8>created_at: u64ciphersuite: u16public_key: Vec<u8>private_key: Vec<u8>Trait Implementations
Sourceimpl Clone for StoredCredential
impl Clone for StoredCredential
Sourcefn clone(&self) -> StoredCredential
fn clone(&self) -> StoredCredential
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoredCredential
impl Debug for StoredCredential
Sourceimpl<'de> Deserialize<'de> for StoredCredential
impl<'de> Deserialize<'de> for StoredCredential
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for StoredCredential
impl Entity for StoredCredential
Sourceconst COLLECTION_NAME: &'static str = "mls_credentials"
const COLLECTION_NAME: &'static str = "mls_credentials"
The table name for this entity
Sourcefn get(
conn: &Connection,
key: &Sha256Hash,
) -> CryptoKeystoreResult<Option<Self>>
fn get( conn: &Connection, key: &Sha256Hash, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for StoredCredential
impl EntityDatabaseMutation for StoredCredential
Sourcetype AutoGeneratedFields = u64
type AutoGeneratedFields = u64
The
pre_save method might generate or update some fields of the item. The canonical example is an updated_at
field. Read moreSourcefn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
fn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
Adjust self before saving. Read more
Sourcefn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
fn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
Use the transaction’s interface to save this entity to the database
Sourcefn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
fn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
Use the transaction’s interface to count the number of entities of this type in the database.
Sourcefn delete(tx: &Transaction<'_>, id: &Sha256Hash) -> CryptoKeystoreResult<bool>
fn delete(tx: &Transaction<'_>, id: &Sha256Hash) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourceimpl PartialEq for StoredCredential
impl PartialEq for StoredCredential
Sourcefn eq(&self, other: &StoredCredential) -> bool
fn eq(&self, other: &StoredCredential) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PrimaryKey for StoredCredential
impl PrimaryKey for StoredCredential
Sourcetype PrimaryKey = Sha256Hash
type PrimaryKey = Sha256Hash
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl<'a> SearchableEntity<CredentialFindFilters<'a>> for StoredCredential
impl<'a> SearchableEntity<CredentialFindFilters<'a>> for StoredCredential
Sourcefn find_all_matching(
conn: &Connection,
filters: &CredentialFindFilters<'a>,
) -> CryptoKeystoreResult<Vec<Self>>
fn find_all_matching( conn: &Connection, filters: &CredentialFindFilters<'a>, ) -> CryptoKeystoreResult<Vec<Self>>
Find all entities matching the search key. Read more
Sourceimpl Serialize for StoredCredential
impl Serialize for StoredCredential
Sourceimpl ToValue for StoredCredential
impl ToValue for StoredCredential
Sourceimpl Zeroize for StoredCredential
impl Zeroize for StoredCredential
impl Eq for StoredCredential
impl StructuralPartialEq for StoredCredential