pub struct StoredE2eiEnrollment {
pub id: Vec<u8>,
pub content: Vec<u8>,
}Expand description
Entity representing an enrollment instance used to fetch a x509 certificate and persisted when context switches and the memory it lives in is about to be erased
Fields
id: Vec<u8>content: Vec<u8>Trait Implementations
Sourceimpl BorrowPrimaryKey for StoredE2eiEnrollment
impl BorrowPrimaryKey for StoredE2eiEnrollment
type BorrowedPrimaryKey = [u8]
Sourcefn borrow_primary_key(&self) -> &Self::BorrowedPrimaryKey
fn borrow_primary_key(&self) -> &Self::BorrowedPrimaryKey
Borrow this entity’s primary key without copying any data. Read more
Sourceimpl Clone for StoredE2eiEnrollment
impl Clone for StoredE2eiEnrollment
Sourcefn clone(&self) -> StoredE2eiEnrollment
fn clone(&self) -> StoredE2eiEnrollment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoredE2eiEnrollment
impl Debug for StoredE2eiEnrollment
Sourceimpl<'de> Deserialize<'de> for StoredE2eiEnrollment
impl<'de> Deserialize<'de> for StoredE2eiEnrollment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for StoredE2eiEnrollment
impl Entity for StoredE2eiEnrollment
Sourceconst COLLECTION_NAME: &'static str = "e2ei_enrollment"
const COLLECTION_NAME: &'static str = "e2ei_enrollment"
The table name for this entity
Sourcefn get(
conn: &Connection,
key: &Self::PrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>
fn get( conn: &Connection, key: &Self::PrimaryKey, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for StoredE2eiEnrollment
impl EntityDatabaseMutation for StoredE2eiEnrollment
Sourcetype AutoGeneratedFields = ()
type AutoGeneratedFields = ()
The
pre_save method might generate or update some fields of the item. The canonical example is an updated_at
field. Read moreSourcefn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
fn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
Use the transaction’s interface to save this entity to the database
Sourcefn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
fn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
Use the transaction’s interface to count the number of entities of this type in the database.
Sourcefn delete(
tx: &Transaction<'_>,
id: &Self::PrimaryKey,
) -> CryptoKeystoreResult<bool>
fn delete( tx: &Transaction<'_>, id: &Self::PrimaryKey, ) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourcefn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
fn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
Adjust self before saving. Read more
Sourceimpl EntityDeleteBorrowed for StoredE2eiEnrollment
impl EntityDeleteBorrowed for StoredE2eiEnrollment
Sourcefn delete_borrowed(
tx: &Transaction<'_>,
id: &<Self as BorrowPrimaryKey>::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<bool>
fn delete_borrowed( tx: &Transaction<'_>, id: &<Self as BorrowPrimaryKey>::BorrowedPrimaryKey, ) -> CryptoKeystoreResult<bool>
Delete an entity by a borrowed form of its primary key.
Sourceimpl EntityGetBorrowed for StoredE2eiEnrollment
impl EntityGetBorrowed for StoredE2eiEnrollment
Sourcefn get_borrowed(
conn: &Connection,
key: &Self::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>where
for<'pk> &'pk Self::BorrowedPrimaryKey: KeyType,
fn get_borrowed(
conn: &Connection,
key: &Self::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>where
for<'pk> &'pk Self::BorrowedPrimaryKey: KeyType,
Get an entity by a borrowed form of its primary key.
Sourceimpl PartialEq for StoredE2eiEnrollment
impl PartialEq for StoredE2eiEnrollment
Sourcefn eq(&self, other: &StoredE2eiEnrollment) -> bool
fn eq(&self, other: &StoredE2eiEnrollment) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PrimaryKey for StoredE2eiEnrollment
impl PrimaryKey for StoredE2eiEnrollment
Sourcetype PrimaryKey = Vec<u8>
type PrimaryKey = Vec<u8>
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl Serialize for StoredE2eiEnrollment
impl Serialize for StoredE2eiEnrollment
Sourceimpl ToValue for StoredE2eiEnrollment
impl ToValue for StoredE2eiEnrollment
Sourceimpl Zeroize for StoredE2eiEnrollment
impl Zeroize for StoredE2eiEnrollment
impl Eq for StoredE2eiEnrollment
impl StructuralPartialEq for StoredE2eiEnrollment