pub struct StoredEpochEncryptionKeypair {
pub conversation_id: Vec<u8>,
pub own_leaf_idx: u32,
pub epoch: u64,
pub keypairs: Vec<u8>,
}Expand description
Entity representing a list of StoredEncryptionKeyPair
Fields
conversation_id: Vec<u8>own_leaf_idx: u32epoch: u64keypairs: Vec<u8>Trait Implementations
Sourceimpl BorrowPrimaryKey for StoredEpochEncryptionKeypair
impl BorrowPrimaryKey for StoredEpochEncryptionKeypair
type BorrowedPrimaryKey<'a> = StoredEpochEncryptionKeypairPkRef<'a>
Sourcefn borrow_primary_key(&self) -> Self::BorrowedPrimaryKey<'_>
fn borrow_primary_key(&self) -> Self::BorrowedPrimaryKey<'_>
Borrow this entity’s primary key without copying any data. Read more
Sourceimpl Clone for StoredEpochEncryptionKeypair
impl Clone for StoredEpochEncryptionKeypair
Sourcefn clone(&self) -> StoredEpochEncryptionKeypair
fn clone(&self) -> StoredEpochEncryptionKeypair
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoredEpochEncryptionKeypair
impl Debug for StoredEpochEncryptionKeypair
Sourceimpl<'de> Deserialize<'de> for StoredEpochEncryptionKeypair
impl<'de> Deserialize<'de> for StoredEpochEncryptionKeypair
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for StoredEpochEncryptionKeypair
impl Entity for StoredEpochEncryptionKeypair
Sourceconst TABLE_NAME: &'static str = "epoch_encryption_keypairs"
const TABLE_NAME: &'static str = "epoch_encryption_keypairs"
The name of the SQL table for this entity
Sourcefn get(
conn: &Connection,
key: &Self::PrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>
fn get( conn: &Connection, key: &Self::PrimaryKey, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for StoredEpochEncryptionKeypair
impl EntityDatabaseMutation for StoredEpochEncryptionKeypair
Sourcefn save<'a, Tx>(&self, tx: &'a Tx) -> CryptoKeystoreResult<()>
fn save<'a, Tx>(&self, tx: &'a Tx) -> CryptoKeystoreResult<()>
Save this entity to the database in the context of this transaction. Read more
Sourcefn delete<'a, Tx>(
tx: &'a Tx,
id: &Self::PrimaryKey,
) -> CryptoKeystoreResult<bool>
fn delete<'a, Tx>( tx: &'a Tx, id: &Self::PrimaryKey, ) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourceimpl EntityDeleteBorrowed for StoredEpochEncryptionKeypair
impl EntityDeleteBorrowed for StoredEpochEncryptionKeypair
Sourcefn delete_borrowed<'a, Tx>(
tx: &'a Tx,
key: <Self as BorrowPrimaryKey>::BorrowedPrimaryKey<'_>,
) -> CryptoKeystoreResult<bool>
fn delete_borrowed<'a, Tx>( tx: &'a Tx, key: <Self as BorrowPrimaryKey>::BorrowedPrimaryKey<'_>, ) -> CryptoKeystoreResult<bool>
Delete an entity by a borrowed form of its primary key.
Sourceimpl EntityGetBorrowed for StoredEpochEncryptionKeypair
impl EntityGetBorrowed for StoredEpochEncryptionKeypair
Sourcefn get_borrowed(
conn: &Connection,
key: Self::BorrowedPrimaryKey<'_>,
) -> CryptoKeystoreResult<Option<Self>>
fn get_borrowed( conn: &Connection, key: Self::BorrowedPrimaryKey<'_>, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by a borrowed form of its primary key.
Sourceimpl PartialEq for StoredEpochEncryptionKeypair
impl PartialEq for StoredEpochEncryptionKeypair
Sourcefn eq(&self, other: &StoredEpochEncryptionKeypair) -> bool
fn eq(&self, other: &StoredEpochEncryptionKeypair) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PrimaryKey for StoredEpochEncryptionKeypair
impl PrimaryKey for StoredEpochEncryptionKeypair
Sourcetype PrimaryKey = StoredEpochEncryptionKeypairPk
type PrimaryKey = StoredEpochEncryptionKeypairPk
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl Zeroize for StoredEpochEncryptionKeypair
impl Zeroize for StoredEpochEncryptionKeypair
impl Eq for StoredEpochEncryptionKeypair
impl StructuralPartialEq for StoredEpochEncryptionKeypair