StoredEpochEncryptionKeypairPkRef

Struct StoredEpochEncryptionKeypairPkRef 

pub struct StoredEpochEncryptionKeypairPkRef<'a> {
    pub conversation_id: &'a ConversationIdRef,
    pub own_leaf_idx: u32,
    pub epoch: u64,
}
Borrowed primary key type for StoredEpochEncryptionKeypair

Fields

conversation_id: &'a ConversationIdRefown_leaf_idx: u32epoch: u64

Implementations

Source

impl<'a> StoredEpochEncryptionKeypairPkRef<'a>

pub fn parse_bytes(bytes: &'a [u8]) -> CryptoKeystoreResult<Self>

Parse this PK from its binary representation

OpenMLS assumes that all primary keys are byte slices, and designed its trait structure accordingly. So we have to be able to parse a (probably-freshly-constructed) slice into a discrete type.

pub fn new(conversation_id: &'a [u8], own_leaf_idx: u32, epoch: u64) -> Self

Construct a pk ref from the requisite data