pub struct StoredPskBundle {
pub psk_id: Vec<u8>,
pub psk: Vec<u8>,
}Expand description
Entity representing a persisted PSK Bundle
Fields
psk_id: Vec<u8>psk: Vec<u8>Trait Implementations
Sourceimpl BorrowPrimaryKey for StoredPskBundle
impl BorrowPrimaryKey for StoredPskBundle
type BorrowedPrimaryKey = [u8]
Sourcefn borrow_primary_key(&self) -> &Self::BorrowedPrimaryKey
fn borrow_primary_key(&self) -> &Self::BorrowedPrimaryKey
Borrow this entity’s primary key without copying any data. Read more
Sourceimpl Clone for StoredPskBundle
impl Clone for StoredPskBundle
Sourcefn clone(&self) -> StoredPskBundle
fn clone(&self) -> StoredPskBundle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoredPskBundle
impl Debug for StoredPskBundle
Sourceimpl<'de> Deserialize<'de> for StoredPskBundle
impl<'de> Deserialize<'de> for StoredPskBundle
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for StoredPskBundle
impl Entity for StoredPskBundle
Sourcefn get<'life0, 'life1, 'async_trait>(
conn: &'life0 mut Self::ConnectionType,
key: &'life1 Self::PrimaryKey,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<Option<Self>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get<'life0, 'life1, 'async_trait>(
conn: &'life0 mut Self::ConnectionType,
key: &'life1 Self::PrimaryKey,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<Option<Self>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Get an entity by its primary key. Read more
Sourcefn count<'life0, 'async_trait>(
conn: &'life0 mut Self::ConnectionType,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<u32>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn count<'life0, 'async_trait>(
conn: &'life0 mut Self::ConnectionType,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<u32>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Count the number of entities of this type in the database.
Sourcefn load_all<'life0, 'async_trait>(
conn: &'life0 mut Self::ConnectionType,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<Vec<Self>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn load_all<'life0, 'async_trait>(
conn: &'life0 mut Self::ConnectionType,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<Vec<Self>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Retrieve all entities of this type from the database.
Sourceimpl EntityBase for StoredPskBundle
impl EntityBase for StoredPskBundle
Sourceconst COLLECTION_NAME: &'static str = "mls_psk_bundles"
const COLLECTION_NAME: &'static str = "mls_psk_bundles"
Beware: if you change the value of this constant on any WASM entity, you’ll need to do a data migration
not only because it is used as reference to the object store names but also for the value of the aad.
type ConnectionType = SqlCipherConnection
fn to_transaction_entity(self) -> Entity
fn downcast<T: EntityBase>(&self) -> Option<&T>
fn downcast_arc<T>(self: Arc<Self>) -> Option<Arc<T>>
Sourceimpl<'a> EntityDatabaseMutation<'a> for StoredPskBundle
impl<'a> EntityDatabaseMutation<'a> for StoredPskBundle
type Transaction = TransactionWrapper<'a>
Sourcetype AutoGeneratedFields = ()
type AutoGeneratedFields = ()
The
pre_save method might generate or update some fields of the item. The canonical example is an updated_at
field. Read moreSourcefn save<'life0, 'async_trait>(
&'a self,
tx: &'life0 Self::Transaction,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'a: 'async_trait,
'life0: 'async_trait,
fn save<'life0, 'async_trait>(
&'a self,
tx: &'life0 Self::Transaction,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'a: 'async_trait,
'life0: 'async_trait,
Use the transaction’s interface to save this entity to the database
Sourcefn count<'life0, 'async_trait>(
tx: &'life0 Self::Transaction,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<u32>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn count<'life0, 'async_trait>(
tx: &'life0 Self::Transaction,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<u32>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Use the transaction’s interface to count the number of entities of this type in the database.
Sourcefn delete<'life0, 'life1, 'async_trait>(
tx: &'life0 Self::Transaction,
id: &'life1 Self::PrimaryKey,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<bool>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn delete<'life0, 'life1, 'async_trait>(
tx: &'life0 Self::Transaction,
id: &'life1 Self::PrimaryKey,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<bool>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Use the transaction’s inteface to delete this entity from the database. Read more
Sourceimpl<'a> EntityDeleteBorrowed<'a> for StoredPskBundle
impl<'a> EntityDeleteBorrowed<'a> for StoredPskBundle
Sourcefn delete_borrowed<'life0, 'life1, 'async_trait>(
tx: &'life0 Self::Transaction,
id: &'life1 Self::BorrowedPrimaryKey,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<bool>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn delete_borrowed<'life0, 'life1, 'async_trait>(
tx: &'life0 Self::Transaction,
id: &'life1 Self::BorrowedPrimaryKey,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<bool>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Delete an entity by a borrowed form of its primary key.
Sourceimpl EntityGetBorrowed for StoredPskBundle
impl EntityGetBorrowed for StoredPskBundle
Sourcefn get_borrowed<'life0, 'life1, 'async_trait>(
conn: &'life0 mut Self::ConnectionType,
key: &'life1 Self::BorrowedPrimaryKey,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<Option<Self>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_borrowed<'life0, 'life1, 'async_trait>(
conn: &'life0 mut Self::ConnectionType,
key: &'life1 Self::BorrowedPrimaryKey,
) -> Pin<Box<dyn Future<Output = CryptoKeystoreResult<Option<Self>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Get an entity by a borrowed form of its primary key.
Sourceimpl PartialEq for StoredPskBundle
impl PartialEq for StoredPskBundle
Sourceimpl PrimaryKey for StoredPskBundle
impl PrimaryKey for StoredPskBundle
Sourcetype PrimaryKey = Vec<u8>
type PrimaryKey = Vec<u8>
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl Serialize for StoredPskBundle
impl Serialize for StoredPskBundle
Sourceimpl ToValue for StoredPskBundle
impl ToValue for StoredPskBundle
Sourceimpl UnifiedEntity for StoredPskBundle
impl UnifiedEntity for StoredPskBundle
Sourceconst COLLECTION_NAME: &'static str = "mls_psk_bundles"
const COLLECTION_NAME: &'static str = "mls_psk_bundles"
The table name for this entity
Sourcefn get(conn: &Connection, key: &Vec<u8>) -> CryptoKeystoreResult<Option<Self>>
fn get(conn: &Connection, key: &Vec<u8>) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl UnifiedEntityDatabaseMutation for StoredPskBundle
impl UnifiedEntityDatabaseMutation for StoredPskBundle
Sourcetype AutoGeneratedFields = ()
type AutoGeneratedFields = ()
The
pre_save method might generate or update some fields of the item. The canonical example is an updated_at
field. Read moreSourcefn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
fn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
Use the transaction’s interface to save this entity to the database
Sourcefn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
fn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
Use the transaction’s interface to count the number of entities of this type in the database.
Sourcefn delete(tx: &Transaction<'_>, id: &Vec<u8>) -> CryptoKeystoreResult<bool>
fn delete(tx: &Transaction<'_>, id: &Vec<u8>) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourcefn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
fn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
Adjust self before saving. Read more
Sourceimpl UnifiedEntityDeleteBorrowed for StoredPskBundle
impl UnifiedEntityDeleteBorrowed for StoredPskBundle
Sourcefn delete_borrowed(
tx: &Transaction<'_>,
id: &[u8],
) -> CryptoKeystoreResult<bool>
fn delete_borrowed( tx: &Transaction<'_>, id: &[u8], ) -> CryptoKeystoreResult<bool>
Delete an entity by a borrowed form of its primary key.
Sourceimpl UnifiedEntityGetBorrowed for StoredPskBundle
impl UnifiedEntityGetBorrowed for StoredPskBundle
Sourcefn get_borrowed(
conn: &Connection,
key: &[u8],
) -> CryptoKeystoreResult<Option<Self>>
fn get_borrowed( conn: &Connection, key: &[u8], ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by a borrowed form of its primary key.
Sourceimpl Zeroize for StoredPskBundle
impl Zeroize for StoredPskBundle
impl Eq for StoredPskBundle
impl StructuralPartialEq for StoredPskBundle