pub struct TargetedMessageRxCounter {
pub conversation_id: ConversationId,
pub sender: u32,
pub epoch: u64,
pub count: u32,
}Fields
conversation_id: ConversationIdsender: u32epoch: u64count: u32Trait Implementations
Sourceimpl BorrowPrimaryKey for TargetedMessageRxCounter
impl BorrowPrimaryKey for TargetedMessageRxCounter
type BorrowedPrimaryKey<'a> = MessageRxCounterPkRef<'a>
Sourcefn borrow_primary_key(&self) -> Self::BorrowedPrimaryKey<'_>
fn borrow_primary_key(&self) -> Self::BorrowedPrimaryKey<'_>
Borrow this entity’s primary key without copying any data. Read more
Sourceimpl Clone for TargetedMessageRxCounter
impl Clone for TargetedMessageRxCounter
Sourcefn clone(&self) -> TargetedMessageRxCounter
fn clone(&self) -> TargetedMessageRxCounter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TargetedMessageRxCounter
impl Debug for TargetedMessageRxCounter
Sourceimpl DeletableBySearchKey<ConversationEpochsOlderThan> for TargetedMessageRxCounter
impl DeletableBySearchKey<ConversationEpochsOlderThan> for TargetedMessageRxCounter
Sourcefn delete_all_matching<'a, Tx>(
tx: &'a Tx,
conversation_epoch: &ConversationEpochsOlderThan,
) -> CryptoKeystoreResult<()>
fn delete_all_matching<'a, Tx>( tx: &'a Tx, conversation_epoch: &ConversationEpochsOlderThan, ) -> CryptoKeystoreResult<()>
Delete all entities matching the search key. Read more
Sourceimpl<'de> Deserialize<'de> for TargetedMessageRxCounter
impl<'de> Deserialize<'de> for TargetedMessageRxCounter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for TargetedMessageRxCounter
impl Entity for TargetedMessageRxCounter
Sourceconst TABLE_NAME: &'static str = Self::TABLE_NAME
const TABLE_NAME: &'static str = Self::TABLE_NAME
The name of the SQL table for this entity
Sourcefn get(
conn: &Connection,
key: &MessageRxCounterPk,
) -> CryptoKeystoreResult<Option<Self>>
fn get( conn: &Connection, key: &MessageRxCounterPk, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for TargetedMessageRxCounter
impl EntityDatabaseMutation for TargetedMessageRxCounter
Sourcefn save<'a, Tx>(&self, tx: &'a Tx) -> CryptoKeystoreResult<()>
fn save<'a, Tx>(&self, tx: &'a Tx) -> CryptoKeystoreResult<()>
Save this entity to the database in the context of this transaction. Read more
Sourcefn delete<'a, Tx>(
tx: &'a Tx,
primary_key: &MessageRxCounterPk,
) -> CryptoKeystoreResult<bool>
fn delete<'a, Tx>( tx: &'a Tx, primary_key: &MessageRxCounterPk, ) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourceimpl EntityDeleteBorrowed for TargetedMessageRxCounter
impl EntityDeleteBorrowed for TargetedMessageRxCounter
Sourcefn delete_borrowed<'a, Tx>(
tx: &'a Tx,
key: Self::BorrowedPrimaryKey<'_>,
) -> CryptoKeystoreResult<bool>
fn delete_borrowed<'a, Tx>( tx: &'a Tx, key: Self::BorrowedPrimaryKey<'_>, ) -> CryptoKeystoreResult<bool>
Delete an entity by a borrowed form of its primary key.
Sourceimpl EntityGetBorrowed for TargetedMessageRxCounter
impl EntityGetBorrowed for TargetedMessageRxCounter
Sourcefn get_borrowed(
conn: &Connection,
key: Self::BorrowedPrimaryKey<'_>,
) -> CryptoKeystoreResult<Option<Self>>
fn get_borrowed( conn: &Connection, key: Self::BorrowedPrimaryKey<'_>, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by a borrowed form of its primary key.
impl Eq for TargetedMessageRxCounter
Sourceimpl PartialEq for TargetedMessageRxCounter
impl PartialEq for TargetedMessageRxCounter
Sourcefn eq(&self, other: &TargetedMessageRxCounter) -> bool
fn eq(&self, other: &TargetedMessageRxCounter) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PrimaryKey for TargetedMessageRxCounter
impl PrimaryKey for TargetedMessageRxCounter
Sourcetype PrimaryKey = MessageRxCounterPk
type PrimaryKey = MessageRxCounterPk
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl SearchableEntity<ConversationEpochsOlderThan> for TargetedMessageRxCounter
impl SearchableEntity<ConversationEpochsOlderThan> for TargetedMessageRxCounter
Sourcefn find_all_matching(
conn: &Connection,
conversation_epoch: &ConversationEpochsOlderThan,
) -> CryptoKeystoreResult<Vec<Self>>
fn find_all_matching( conn: &Connection, conversation_epoch: &ConversationEpochsOlderThan, ) -> CryptoKeystoreResult<Vec<Self>>
Find all entities matching the search key. Read more
Sourceimpl Serialize for TargetedMessageRxCounter
impl Serialize for TargetedMessageRxCounter
impl StructuralPartialEq for TargetedMessageRxCounter
Sourceimpl ToValue for TargetedMessageRxCounter
impl ToValue for TargetedMessageRxCounter