pub struct TargetedMessageTxCounter {
pub conversation_id: Vec<u8>,
pub receiver: u32,
pub count: u32,
}Fields
conversation_id: Vec<u8>receiver: u32count: u32Trait Implementations
Sourceimpl Clone for TargetedMessageTxCounter
impl Clone for TargetedMessageTxCounter
Sourcefn clone(&self) -> TargetedMessageTxCounter
fn clone(&self) -> TargetedMessageTxCounter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TargetedMessageTxCounter
impl Debug for TargetedMessageTxCounter
Sourceimpl DeletableBySearchKey<ConversationId> for TargetedMessageTxCounter
impl DeletableBySearchKey<ConversationId> for TargetedMessageTxCounter
Sourcefn delete_all_matching(
tx: &Transaction<'_>,
conversation_id: &ConversationId,
) -> CryptoKeystoreResult<()>
fn delete_all_matching( tx: &Transaction<'_>, conversation_id: &ConversationId, ) -> CryptoKeystoreResult<()>
Delete all entities matching the search key. Read more
Sourceimpl<'de> Deserialize<'de> for TargetedMessageTxCounter
impl<'de> Deserialize<'de> for TargetedMessageTxCounter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for TargetedMessageTxCounter
impl Entity for TargetedMessageTxCounter
Sourceconst TABLE_NAME: &'static str = Self::TABLE_NAME
const TABLE_NAME: &'static str = Self::TABLE_NAME
The name of the SQL table for this entity
Sourcefn get(
conn: &Connection,
key: &TargetedMessageTxCounterPk,
) -> CryptoKeystoreResult<Option<Self>>
fn get( conn: &Connection, key: &TargetedMessageTxCounterPk, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for TargetedMessageTxCounter
impl EntityDatabaseMutation for TargetedMessageTxCounter
Sourcetype AutoGeneratedFields = ()
type AutoGeneratedFields = ()
The
pre_save method might generate or update some fields of the item. The canonical example is an updated_at
field. Read moreSourcefn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
fn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
Use the transaction’s interface to save this entity to the database
Sourcefn delete(
tx: &Transaction<'_>,
primary_key: &TargetedMessageTxCounterPk,
) -> CryptoKeystoreResult<bool>
fn delete( tx: &Transaction<'_>, primary_key: &TargetedMessageTxCounterPk, ) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourcefn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
fn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
Adjust self before saving. Read more
impl Eq for TargetedMessageTxCounter
Sourceimpl PartialEq for TargetedMessageTxCounter
impl PartialEq for TargetedMessageTxCounter
Sourcefn eq(&self, other: &TargetedMessageTxCounter) -> bool
fn eq(&self, other: &TargetedMessageTxCounter) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PrimaryKey for TargetedMessageTxCounter
impl PrimaryKey for TargetedMessageTxCounter
Sourcetype PrimaryKey = TargetedMessageTxCounterPk
type PrimaryKey = TargetedMessageTxCounterPk
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl SearchableEntity<ConversationId> for TargetedMessageTxCounter
impl SearchableEntity<ConversationId> for TargetedMessageTxCounter
Sourcefn find_all_matching(
conn: &Connection,
conversation_id: &ConversationId,
) -> CryptoKeystoreResult<Vec<Self>>
fn find_all_matching( conn: &Connection, conversation_id: &ConversationId, ) -> CryptoKeystoreResult<Vec<Self>>
Find all entities matching the search key. Read more
Sourceimpl Serialize for TargetedMessageTxCounter
impl Serialize for TargetedMessageTxCounter
impl StructuralPartialEq for TargetedMessageTxCounter
Sourceimpl ToValue for TargetedMessageTxCounter
impl ToValue for TargetedMessageTxCounter