pub struct TntMessageTxCounter {
pub conversation_id: ConversationId,
pub count: u32,
}Fields
conversation_id: ConversationIdcount: u32Trait Implementations
Sourceimpl BorrowPrimaryKey for TntMessageTxCounter
impl BorrowPrimaryKey for TntMessageTxCounter
type BorrowedPrimaryKey<'a> = &'a ConversationIdRef
Sourcefn borrow_primary_key(&self) -> Self::BorrowedPrimaryKey<'_>
fn borrow_primary_key(&self) -> Self::BorrowedPrimaryKey<'_>
Borrow this entity’s primary key without copying any data. Read more
Sourceimpl Clone for TntMessageTxCounter
impl Clone for TntMessageTxCounter
Sourcefn clone(&self) -> TntMessageTxCounter
fn clone(&self) -> TntMessageTxCounter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TntMessageTxCounter
impl Debug for TntMessageTxCounter
Sourceimpl<'de> Deserialize<'de> for TntMessageTxCounter
impl<'de> Deserialize<'de> for TntMessageTxCounter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for TntMessageTxCounter
impl Entity for TntMessageTxCounter
Sourceconst TABLE_NAME: &str = Self::TABLE_NAME
const TABLE_NAME: &str = Self::TABLE_NAME
The name of the SQL table for this entity
Sourcefn get(
conn: &Connection,
key: &ConversationId,
) -> CryptoKeystoreResult<Option<Self>>
fn get( conn: &Connection, key: &ConversationId, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for TntMessageTxCounter
impl EntityDatabaseMutation for TntMessageTxCounter
Sourcefn save<'a, Tx>(&self, tx: &'a Tx) -> CryptoKeystoreResult<()>
fn save<'a, Tx>(&self, tx: &'a Tx) -> CryptoKeystoreResult<()>
Save this entity to the database in the context of this transaction. Read more
Sourcefn delete<'a, Tx>(
tx: &'a Tx,
primary_key: &Self::PrimaryKey,
) -> CryptoKeystoreResult<bool>
fn delete<'a, Tx>( tx: &'a Tx, primary_key: &Self::PrimaryKey, ) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourceimpl EntityDeleteBorrowed for TntMessageTxCounter
impl EntityDeleteBorrowed for TntMessageTxCounter
Sourcefn delete_borrowed<'a, Tx>(
tx: &'a Tx,
id: Self::BorrowedPrimaryKey<'_>,
) -> CryptoKeystoreResult<bool>
fn delete_borrowed<'a, Tx>( tx: &'a Tx, id: Self::BorrowedPrimaryKey<'_>, ) -> CryptoKeystoreResult<bool>
Delete an entity by a borrowed form of its primary key.
Sourceimpl EntityGetBorrowed for TntMessageTxCounter
impl EntityGetBorrowed for TntMessageTxCounter
Sourcefn get_borrowed(
conn: &Connection,
key: Self::BorrowedPrimaryKey<'_>,
) -> CryptoKeystoreResult<Option<Self>>
fn get_borrowed( conn: &Connection, key: Self::BorrowedPrimaryKey<'_>, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by a borrowed form of its primary key.
impl Eq for TntMessageTxCounter
Sourceimpl PartialEq for TntMessageTxCounter
impl PartialEq for TntMessageTxCounter
Sourcefn eq(&self, other: &TntMessageTxCounter) -> bool
fn eq(&self, other: &TntMessageTxCounter) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PrimaryKey for TntMessageTxCounter
impl PrimaryKey for TntMessageTxCounter
Sourcetype PrimaryKey = ConversationId
type PrimaryKey = ConversationId
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl Serialize for TntMessageTxCounter
impl Serialize for TntMessageTxCounter
impl StructuralPartialEq for TntMessageTxCounter