pub struct TntSecret {
pub conversation_id: ConversationId,
pub epoch: u64,
pub hpke_private_key: Vec<u8>,
pub group_context: Vec<u8>,
pub targeted_message_psk: Vec<u8>,
}Fields
conversation_id: ConversationIdepoch: u64hpke_private_key: Vec<u8>group_context: Vec<u8>targeted_message_psk: Vec<u8>Trait Implementations
Sourceimpl BorrowPrimaryKey for TntSecret
impl BorrowPrimaryKey for TntSecret
type BorrowedPrimaryKey<'a> = TntSecretPkRef<'a>
Sourcefn borrow_primary_key(&self) -> Self::BorrowedPrimaryKey<'_>
fn borrow_primary_key(&self) -> Self::BorrowedPrimaryKey<'_>
Borrow this entity’s primary key without copying any data. Read more
Sourceimpl DeletableBySearchKey<ConversationEpochsOlderThan> for TntSecret
impl DeletableBySearchKey<ConversationEpochsOlderThan> for TntSecret
Sourcefn delete_all_matching<'a, Tx>(
tx: &'a Tx,
conversation_epoch: &ConversationEpochsOlderThan,
) -> CryptoKeystoreResult<()>
fn delete_all_matching<'a, Tx>( tx: &'a Tx, conversation_epoch: &ConversationEpochsOlderThan, ) -> CryptoKeystoreResult<()>
Delete all entities matching the search key. Read more
Sourceimpl<'de> Deserialize<'de> for TntSecret
impl<'de> Deserialize<'de> for TntSecret
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for TntSecret
impl Entity for TntSecret
Sourceconst TABLE_NAME: &str = Self::TABLE_NAME
const TABLE_NAME: &str = Self::TABLE_NAME
The name of the SQL table for this entity
Sourcefn get(
conn: &Connection,
key: &TntSecretPk,
) -> CryptoKeystoreResult<Option<Self>>
fn get( conn: &Connection, key: &TntSecretPk, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for TntSecret
impl EntityDatabaseMutation for TntSecret
Sourcefn save<'a, Tx>(&self, tx: &'a Tx) -> CryptoKeystoreResult<()>
fn save<'a, Tx>(&self, tx: &'a Tx) -> CryptoKeystoreResult<()>
Save this entity to the database in the context of this transaction. Read more
Sourcefn delete<'a, Tx>(tx: &'a Tx, key: &TntSecretPk) -> CryptoKeystoreResult<bool>
fn delete<'a, Tx>(tx: &'a Tx, key: &TntSecretPk) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourceimpl EntityDeleteBorrowed for TntSecret
impl EntityDeleteBorrowed for TntSecret
Sourcefn delete_borrowed<'a, Tx>(
tx: &'a Tx,
key: Self::BorrowedPrimaryKey<'_>,
) -> CryptoKeystoreResult<bool>
fn delete_borrowed<'a, Tx>( tx: &'a Tx, key: Self::BorrowedPrimaryKey<'_>, ) -> CryptoKeystoreResult<bool>
Delete an entity by a borrowed form of its primary key.
Sourceimpl EntityGetBorrowed for TntSecret
impl EntityGetBorrowed for TntSecret
Sourcefn get_borrowed(
conn: &Connection,
key: Self::BorrowedPrimaryKey<'_>,
) -> CryptoKeystoreResult<Option<Self>>
fn get_borrowed( conn: &Connection, key: Self::BorrowedPrimaryKey<'_>, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by a borrowed form of its primary key.
impl Eq for TntSecret
Sourceimpl PrimaryKey for TntSecret
impl PrimaryKey for TntSecret
Sourcetype PrimaryKey = TntSecretPk
type PrimaryKey = TntSecretPk
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl SearchableEntity<ConversationEpochsOlderThan> for TntSecret
impl SearchableEntity<ConversationEpochsOlderThan> for TntSecret
Sourcefn find_all_matching(
conn: &Connection,
conversation_epoch: &ConversationEpochsOlderThan,
) -> CryptoKeystoreResult<Vec<Self>>
fn find_all_matching( conn: &Connection, conversation_epoch: &ConversationEpochsOlderThan, ) -> CryptoKeystoreResult<Vec<Self>>
Find all entities matching the search key. Read more
impl StructuralPartialEq for TntSecret