pub struct X509IntermediateCert {
pub ski_aki_pair: String,
pub content: Vec<u8>,
}Fields
ski_aki_pair: Stringcontent: Vec<u8>Trait Implementations
Sourceimpl BorrowPrimaryKey for X509IntermediateCert
impl BorrowPrimaryKey for X509IntermediateCert
type BorrowedPrimaryKey = str
Sourcefn borrow_primary_key(&self) -> &Self::BorrowedPrimaryKey
fn borrow_primary_key(&self) -> &Self::BorrowedPrimaryKey
Borrow this entity’s primary key without copying any data. Read more
Sourceimpl Clone for X509IntermediateCert
impl Clone for X509IntermediateCert
Sourcefn clone(&self) -> X509IntermediateCert
fn clone(&self) -> X509IntermediateCert
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for X509IntermediateCert
impl Debug for X509IntermediateCert
Sourceimpl<'de> Deserialize<'de> for X509IntermediateCert
impl<'de> Deserialize<'de> for X509IntermediateCert
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for X509IntermediateCert
impl Entity for X509IntermediateCert
Sourceconst TABLE_NAME: &'static str = "x509_intermediate_certs"
const TABLE_NAME: &'static str = "x509_intermediate_certs"
The name of the SQL table for this entity
Sourcefn get(
conn: &Connection,
key: &Self::PrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>
fn get( conn: &Connection, key: &Self::PrimaryKey, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for X509IntermediateCert
impl EntityDatabaseMutation for X509IntermediateCert
Sourcetype AutoGeneratedFields = ()
type AutoGeneratedFields = ()
The
pre_save method might generate or update some fields of the item. The canonical example is an updated_at
field. Read moreSourcefn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
fn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
Use the transaction’s interface to save this entity to the database
Sourcefn delete(
tx: &Transaction<'_>,
id: &Self::PrimaryKey,
) -> CryptoKeystoreResult<bool>
fn delete( tx: &Transaction<'_>, id: &Self::PrimaryKey, ) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourcefn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
fn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
Adjust self before saving. Read more
Sourceimpl EntityDeleteBorrowed for X509IntermediateCert
impl EntityDeleteBorrowed for X509IntermediateCert
Sourcefn delete_borrowed(
tx: &Transaction<'_>,
id: &<Self as BorrowPrimaryKey>::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<bool>
fn delete_borrowed( tx: &Transaction<'_>, id: &<Self as BorrowPrimaryKey>::BorrowedPrimaryKey, ) -> CryptoKeystoreResult<bool>
Delete an entity by a borrowed form of its primary key.
Sourceimpl EntityGetBorrowed for X509IntermediateCert
impl EntityGetBorrowed for X509IntermediateCert
Sourcefn get_borrowed(
conn: &Connection,
key: &Self::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>where
for<'pk> &'pk Self::BorrowedPrimaryKey: KeyType,
fn get_borrowed(
conn: &Connection,
key: &Self::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>where
for<'pk> &'pk Self::BorrowedPrimaryKey: KeyType,
Get an entity by a borrowed form of its primary key.
Sourceimpl PartialEq for X509IntermediateCert
impl PartialEq for X509IntermediateCert
Sourcefn eq(&self, other: &X509IntermediateCert) -> bool
fn eq(&self, other: &X509IntermediateCert) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PrimaryKey for X509IntermediateCert
impl PrimaryKey for X509IntermediateCert
Sourcetype PrimaryKey = String
type PrimaryKey = String
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl Serialize for X509IntermediateCert
impl Serialize for X509IntermediateCert
Sourceimpl ToValue for X509IntermediateCert
impl ToValue for X509IntermediateCert
Sourceimpl Zeroize for X509IntermediateCert
impl Zeroize for X509IntermediateCert
impl Eq for X509IntermediateCert
impl StructuralPartialEq for X509IntermediateCert