Transaction

Struct Transaction 

pub struct Transaction { /* private fields */ }
This is an in-flight transaction: all operations are buffered in memory, and only applied to the database on commit.

Dropping the transaction without committing performs an implicit rollback.

This type is always wrapped in a UniqueArc, which keeps things efficient, at the cost of prohibiting Clone. In case you need to share this around, there are weak references available via UniqueArc::downgrade. Alternately, wrap the entire thing in an Arc<Mutex<Option<UniqueArc<Self>>>> or similar. Just be aware that you’ll need to take the unique arc out in order to commit.

Implementations

Source

impl Transaction

pub async fn save<E>( &self, entity: E, ) -> CryptoKeystoreResult<E::AutoGeneratedFields>

Save an entity into this transaction.

This is a multi-step process:

  • Adjust the entity by calling its pre_save() method.
  • Store the entity in an internal map.
    • Remove the entity from the set of deleted entities, if it was there.
  • On commit, actually persist the entity into the supplied database.
pub async fn remove<E>(&self, id: &E::PrimaryKey) -> CryptoKeystoreResult<()>

Remove an entity by its primary key.

Where the primary key has a distinct borrowed form, consider Self::remove_borrowed.

Note that this doesn’t return whether or not anything was actually removed because that won’t happen until the transaction is committed.

pub async fn remove_borrowed<E>( &self, id: &E::BorrowedPrimaryKey, ) -> CryptoKeystoreResult<()>

Remove an entity by the borrowed form of its primary key.

Note that this doesn’t return whether or not anything was actually removed because that won’t happen until the transaction is committed.

pub async fn restore<E>( &self, id: &E::BorrowedPrimaryKey, ) -> CryptoKeystoreResult<()>

Restore an entity that was deleted in this transaction by removing it from the deleted list. This is idempotent: if the entity doesn’t exist in the deleted list, do nothing.

NOTE: This will only work if the entity has been added in an earlier transaction, because otherwise, removing its id from the deleted list wouldn’t suffice: we’d need to replay its insertion.