pub struct Database { /* private fields */ }Implementations
Sourceimpl Database
impl Database
pub async fn child_groups( &self, entity: PersistedMlsGroup, ) -> CryptoKeystoreResult<Vec<PersistedMlsGroup>>
pub async fn find_pending_messages_by_conversation_id( &self, conversation_id: &[u8], ) -> CryptoKeystoreResult<Vec<MlsPendingMessage>>
pub async fn remove_pending_messages_by_conversation_id( &self, conversation_id: impl AsRef<[u8]> + Send, ) -> CryptoKeystoreResult<()>
Sourceimpl Database
These impls control the keystore transaction lifecycle.
impl Database
These impls control the keystore transaction lifecycle.
Sourcepub async fn new_transaction(&self) -> CryptoKeystoreResult<()>
pub async fn new_transaction(&self) -> CryptoKeystoreResult<()>
Waits for the current transaction to be committed or rolled back, then starts a new one.
Sourcepub async fn try_new_immediate_transaction(&self) -> CryptoKeystoreResult<()>
pub async fn try_new_immediate_transaction(&self) -> CryptoKeystoreResult<()>
Start a new transaction if no other transaction is currently in progress.
If a transaction is currently in progress, this will produce a TransactionInProgress error.
pub async fn commit_transaction(&self) -> CryptoKeystoreResult<()>
pub async fn rollback_transaction(&self) -> CryptoKeystoreResult<()>
Sourcepub async fn transactionally<R>(
&self,
operation: impl AsyncFnOnce(&KeystoreTransaction) -> CryptoKeystoreResult<R>,
) -> CryptoKeystoreResult<R>
pub async fn transactionally<R>( &self, operation: impl AsyncFnOnce(&KeystoreTransaction) -> CryptoKeystoreResult<R>, ) -> CryptoKeystoreResult<R>
Do an operation on a keystore transaction on this database.
This is a convenience method abstracting over Self::new_transaction,
Self::commit_transaction, and Self::rollback_transaction.
If the operation succeeds, the transaction is committed. Otherwise, it is rolled back.
Sourceimpl Database
These impls are convenience methods to modify the keystore transaction.
impl Database
These impls are convenience methods to modify the keystore transaction.
Be aware that we are likely to remove these in the future: WPB-23951
pub async fn save<E>( &self, entity: E, ) -> CryptoKeystoreResult<E::AutoGeneratedFields>
pub async fn remove<E>(&self, id: &E::PrimaryKey) -> CryptoKeystoreResult<()>where
E: Entity + EntityDatabaseMutation,
pub async fn remove_borrowed<E>( &self, id: &E::BorrowedPrimaryKey, ) -> CryptoKeystoreResult<()>
Sourcepub async fn restore<E>(
&self,
id: &E::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<()>
pub async fn restore<E>( &self, id: &E::BorrowedPrimaryKey, ) -> CryptoKeystoreResult<()>
Restore an entity that was deleted in this transaction by removing it from the deleted list. This is idempotent: if the entity doesn’t exist in the deleted list, do nothing.
NOTE: This will only work if the entity has been added in an earlier transaction, because otherwise, removing its id from the deleted list wouldn’t suffice: we’d need to replay its insertion.
Sourceimpl Database
impl Database
Sourcepub async fn open(
path: &str,
database_key: &DatabaseKey,
) -> CryptoKeystoreResult<Arc<Self>>
pub async fn open( path: &str, database_key: &DatabaseKey, ) -> CryptoKeystoreResult<Arc<Self>>
Open an encrypted Database at the provided location.
When compiled with target_os = "unknown", this opens a database encrypted via
sqlite3-multiple-ciphers using its default encryption mechanism, stored in IndexedDB
via the relaxed-idb shim.
When compiled normally, this opens a database encrypted via sqlcipher at a path in the local filesystem.
Sourcepub fn open_in_memory() -> CryptoKeystoreResult<Arc<Self>>
pub fn open_in_memory() -> CryptoKeystoreResult<Arc<Self>>
Open an in-memory Database.
In-memory databases are never encrypted.
Sourcepub async fn update_key(
&self,
new_key: &DatabaseKey,
) -> CryptoKeystoreResult<()>
pub async fn update_key( &self, new_key: &DatabaseKey, ) -> CryptoKeystoreResult<()>
Change the encryption key for this database.
pub async fn close(self) -> CryptoKeystoreResult<()>
Sourcepub async fn wipe(self) -> CryptoKeystoreResult<()>
pub async fn wipe(self) -> CryptoKeystoreResult<()>
Close and remove this database.
This deletes the database, including its encryption key. Future opens will always succeed with any arbitrary encryption key; they will simply open an empty database.
Sourcepub async fn location(&self) -> Option<String>
pub async fn location(&self) -> Option<String>
Get the location of the database.
Returns None if the database is in-memory.
Sourcepub async fn export_copy(
&self,
destination_path: &str,
) -> CryptoKeystoreResult<()>
pub async fn export_copy( &self, destination_path: &str, ) -> CryptoKeystoreResult<()>
Export a copy of the database to the specified path using VACUUM INTO.
This creates a fully vacuumed and optimized copy of the database. The copy will be encrypted with the same key as the source database.
Arguments
destination_path- The file path where the database copy should be created
Sourceimpl Database
impl Database
Sourcepub async fn mls_fetch_key_packages<V: MlsEntity>(
&self,
count: u32,
) -> CryptoKeystoreResult<Vec<V>>
pub async fn mls_fetch_key_packages<V: MlsEntity>( &self, count: u32, ) -> CryptoKeystoreResult<Vec<V>>
Sourcepub async fn mls_group_exists(&self, group_id: impl AsRef<[u8]> + Send) -> bool
pub async fn mls_group_exists(&self, group_id: impl AsRef<[u8]> + Send) -> bool
Checks if the given MLS group id exists in the keystore Note: in case of any error, this will return false
Arguments
group_id- group/conversation id
Sourcepub async fn mls_group_persist(
&self,
group_id: impl AsRef<[u8]> + Send,
state: &[u8],
parent_group_id: Option<&[u8]>,
) -> CryptoKeystoreResult<()>
pub async fn mls_group_persist( &self, group_id: impl AsRef<[u8]> + Send, state: &[u8], parent_group_id: Option<&[u8]>, ) -> CryptoKeystoreResult<()>
Sourcepub async fn mls_groups_restore(
&self,
) -> CryptoKeystoreResult<HashMap<Vec<u8>, (Option<Vec<u8>>, Vec<u8>)>>
pub async fn mls_groups_restore( &self, ) -> CryptoKeystoreResult<HashMap<Vec<u8>, (Option<Vec<u8>>, Vec<u8>)>>
Loads MlsGroups from the database. It will be returned as a HashMap where the key is
the group/conversation id and the value the group state
Errors
Any common error that can happen during a database connection. IoError being a common error for example.
Sourcepub async fn mls_group_delete(
&self,
group_id: impl AsRef<[u8]> + Send,
) -> CryptoKeystoreResult<()>
pub async fn mls_group_delete( &self, group_id: impl AsRef<[u8]> + Send, ) -> CryptoKeystoreResult<()>
Deletes MlsGroups from the database.
Errors
Any common error that can happen during a database connection. IoError being a common error for example.
Sourcepub async fn mls_pending_groups_save(
&self,
group_id: impl AsRef<[u8]> + Send,
mls_group: &[u8],
custom_configuration: &[u8],
parent_group_id: Option<&[u8]>,
) -> CryptoKeystoreResult<()>
pub async fn mls_pending_groups_save( &self, group_id: impl AsRef<[u8]> + Send, mls_group: &[u8], custom_configuration: &[u8], parent_group_id: Option<&[u8]>, ) -> CryptoKeystoreResult<()>
Saves a MlsGroup in a temporary table (typically used in scenarios where the group cannot
be committed until the backend acknowledges it, like external commits)
Arguments
group_id- group/conversation idmls_group- the group/conversation statecustom_configuration- local group configuration
Errors
Any common error that can happen during a database connection. IoError being a common error for example.
Sourcepub async fn mls_pending_groups_load(
&self,
group_id: impl AsRef<[u8]> + Send,
) -> CryptoKeystoreResult<Option<(Vec<u8>, Vec<u8>)>>
pub async fn mls_pending_groups_load( &self, group_id: impl AsRef<[u8]> + Send, ) -> CryptoKeystoreResult<Option<(Vec<u8>, Vec<u8>)>>
Sourcepub async fn mls_pending_groups_delete(
&self,
group_id: impl AsRef<[u8]> + Send,
) -> CryptoKeystoreResult<()>
pub async fn mls_pending_groups_delete( &self, group_id: impl AsRef<[u8]> + Send, ) -> CryptoKeystoreResult<()>
Sourcepub async fn save_e2ei_enrollment(
&self,
id: &[u8],
content: &[u8],
) -> CryptoKeystoreResult<()>
pub async fn save_e2ei_enrollment( &self, id: &[u8], content: &[u8], ) -> CryptoKeystoreResult<()>
Persists an enrollment instance
Arguments
id- hash of the enrollment and unique identifiercontent- serialized enrollment
Sourcepub async fn pop_e2ei_enrollment(
&self,
id: &[u8],
) -> CryptoKeystoreResult<Option<Vec<u8>>>
pub async fn pop_e2ei_enrollment( &self, id: &[u8], ) -> CryptoKeystoreResult<Option<Vec<u8>>>
Fetches and delete the enrollment instance
Arguments
id- hash of the enrollment and unique identifier
Sourceimpl Database
impl Database
pub async fn proteus_store_prekey( &self, id: u16, prekey: &[u8], ) -> CryptoKeystoreResult<()>