pub struct MlsPendingMessage {
pub foreign_id: Vec<u8>,
pub message: Vec<u8>,
}Expand description
Entity representing a buffered message
Fields
foreign_id: Vec<u8>message: Vec<u8>Trait Implementations
Sourceimpl Clone for MlsPendingMessage
impl Clone for MlsPendingMessage
Sourcefn clone(&self) -> MlsPendingMessage
fn clone(&self) -> MlsPendingMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MlsPendingMessage
impl Debug for MlsPendingMessage
Sourceimpl<'a> DeletableBySearchKey<ConversationId<'a>> for MlsPendingMessage
impl<'a> DeletableBySearchKey<ConversationId<'a>> for MlsPendingMessage
Sourcefn delete_all_matching(
tx: &Transaction<'_>,
conversation_id: &ConversationId<'a>,
) -> CryptoKeystoreResult<()>
fn delete_all_matching( tx: &Transaction<'_>, conversation_id: &ConversationId<'a>, ) -> CryptoKeystoreResult<()>
Delete all entities matching the search key. Read more
Sourceimpl<'de> Deserialize<'de> for MlsPendingMessage
impl<'de> Deserialize<'de> for MlsPendingMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for MlsPendingMessage
impl Entity for MlsPendingMessage
Sourceconst COLLECTION_NAME: &'static str = "mls_pending_messages"
const COLLECTION_NAME: &'static str = "mls_pending_messages"
The table name for this entity
Sourcefn get(
_conn: &Connection,
_key: &MlsPendingMessagePrimaryKey,
) -> CryptoKeystoreResult<Option<Self>>
fn get( _conn: &Connection, _key: &MlsPendingMessagePrimaryKey, ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for MlsPendingMessage
impl EntityDatabaseMutation for MlsPendingMessage
Sourcetype AutoGeneratedFields = ()
type AutoGeneratedFields = ()
The
pre_save method might generate or update some fields of the item. The canonical example is an updated_at
field. Read moreSourcefn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
fn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
Use the transaction’s interface to save this entity to the database
Sourcefn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
fn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
Use the transaction’s interface to count the number of entities of this type in the database.
Sourcefn delete(
_tx: &Transaction<'_>,
_id: &MlsPendingMessagePrimaryKey,
) -> CryptoKeystoreResult<bool>
fn delete( _tx: &Transaction<'_>, _id: &MlsPendingMessagePrimaryKey, ) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourcefn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
fn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
Adjust self before saving. Read more
Sourceimpl From<&MlsPendingMessage> for MlsPendingMessagePrimaryKey
impl From<&MlsPendingMessage> for MlsPendingMessagePrimaryKey
Sourcefn from(value: &MlsPendingMessage) -> Self
fn from(value: &MlsPendingMessage) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for MlsPendingMessage
impl PartialEq for MlsPendingMessage
Sourcefn eq(&self, other: &MlsPendingMessage) -> bool
fn eq(&self, other: &MlsPendingMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PrimaryKey for MlsPendingMessage
impl PrimaryKey for MlsPendingMessage
Sourcetype PrimaryKey = MlsPendingMessagePrimaryKey
type PrimaryKey = MlsPendingMessagePrimaryKey
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl<'a> SearchableEntity<ConversationId<'a>> for MlsPendingMessage
impl<'a> SearchableEntity<ConversationId<'a>> for MlsPendingMessage
Sourcefn find_all_matching(
conn: &Connection,
conversation_id: &ConversationId<'a>,
) -> CryptoKeystoreResult<Vec<Self>>
fn find_all_matching( conn: &Connection, conversation_id: &ConversationId<'a>, ) -> CryptoKeystoreResult<Vec<Self>>
Find all entities matching the search key. Read more
Sourceimpl Serialize for MlsPendingMessage
impl Serialize for MlsPendingMessage
Sourceimpl ToValue for MlsPendingMessage
impl ToValue for MlsPendingMessage
Sourceimpl Zeroize for MlsPendingMessage
impl Zeroize for MlsPendingMessage
impl Eq for MlsPendingMessage
impl StructuralPartialEq for MlsPendingMessage