pub struct PersistedMlsPendingGroup {
pub id: Vec<u8>,
pub state: Vec<u8>,
pub parent_id: Option<Vec<u8>>,
pub custom_configuration: Vec<u8>,
}Expand description
Entity representing a temporarily persisted MlsGroup
Fields
id: Vec<u8>state: Vec<u8>parent_id: Option<Vec<u8>>custom_configuration: Vec<u8>Trait Implementations
Sourceimpl BorrowPrimaryKey for PersistedMlsPendingGroup
impl BorrowPrimaryKey for PersistedMlsPendingGroup
type BorrowedPrimaryKey = [u8]
Sourceimpl Clone for PersistedMlsPendingGroup
impl Clone for PersistedMlsPendingGroup
Sourcefn clone(&self) -> PersistedMlsPendingGroup
fn clone(&self) -> PersistedMlsPendingGroup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PersistedMlsPendingGroup
impl Debug for PersistedMlsPendingGroup
Sourceimpl<'de> Deserialize<'de> for PersistedMlsPendingGroup
impl<'de> Deserialize<'de> for PersistedMlsPendingGroup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for PersistedMlsPendingGroup
impl Entity for PersistedMlsPendingGroup
Sourceconst COLLECTION_NAME: &'static str = "mls_pending_groups"
const COLLECTION_NAME: &'static str = "mls_pending_groups"
The table name for this entity
Sourcefn get(conn: &Connection, key: &Vec<u8>) -> CryptoKeystoreResult<Option<Self>>
fn get(conn: &Connection, key: &Vec<u8>) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for PersistedMlsPendingGroup
impl EntityDatabaseMutation for PersistedMlsPendingGroup
Sourcetype AutoGeneratedFields = ()
type AutoGeneratedFields = ()
The
pre_save method might generate or update some fields of the item. The canonical example is an updated_at
field. Read moreSourcefn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
fn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
Use the transaction’s interface to save this entity to the database
Sourcefn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
fn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
Use the transaction’s interface to count the number of entities of this type in the database.
Sourcefn delete(tx: &Transaction<'_>, id: &Vec<u8>) -> CryptoKeystoreResult<bool>
fn delete(tx: &Transaction<'_>, id: &Vec<u8>) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourcefn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
fn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
Adjust self before saving. Read more
Sourceimpl EntityDeleteBorrowed for PersistedMlsPendingGroup
impl EntityDeleteBorrowed for PersistedMlsPendingGroup
Sourcefn delete_borrowed(
tx: &Transaction<'_>,
id: &[u8],
) -> CryptoKeystoreResult<bool>
fn delete_borrowed( tx: &Transaction<'_>, id: &[u8], ) -> CryptoKeystoreResult<bool>
Delete an entity by a borrowed form of its primary key.
Sourceimpl EntityGetBorrowed for PersistedMlsPendingGroup
impl EntityGetBorrowed for PersistedMlsPendingGroup
Sourcefn get_borrowed(
conn: &Connection,
key: &[u8],
) -> CryptoKeystoreResult<Option<Self>>
fn get_borrowed( conn: &Connection, key: &[u8], ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by a borrowed form of its primary key.
Sourceimpl PartialEq for PersistedMlsPendingGroup
impl PartialEq for PersistedMlsPendingGroup
Sourcefn eq(&self, other: &PersistedMlsPendingGroup) -> bool
fn eq(&self, other: &PersistedMlsPendingGroup) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PrimaryKey for PersistedMlsPendingGroup
impl PrimaryKey for PersistedMlsPendingGroup
Sourcetype PrimaryKey = Vec<u8>
type PrimaryKey = Vec<u8>
Each distinct
PrimaryKey uniquely identifies either 0 or 1 instance. Read moreSourcefn primary_key(&self) -> Self::PrimaryKey
fn primary_key(&self) -> Self::PrimaryKey
Get this entity’s primary key. Read more
Sourceimpl Serialize for PersistedMlsPendingGroup
impl Serialize for PersistedMlsPendingGroup
Sourceimpl ToValue for PersistedMlsPendingGroup
impl ToValue for PersistedMlsPendingGroup
Sourceimpl Zeroize for PersistedMlsPendingGroup
impl Zeroize for PersistedMlsPendingGroup
impl Eq for PersistedMlsPendingGroup
impl StructuralPartialEq for PersistedMlsPendingGroup