pub struct StoredBufferedCommit { /* private fields */ }Expand description
Entity representing a buffered commit.
There should always exist either 0 or 1 of these in the store per conversation. Commits are buffered if not all proposals they reference have yet been received.
We don’t automatically zeroize on drop because the commit data is still encrypted at this point; it is not risky to leave it in memory.
Implementations