pub struct StoredEpochEncryptionKeypairPkRef<'a> {
pub conversation_id: &'a ConversationIdRef,
pub own_leaf_idx: u32,
pub epoch: u64,
}Expand description
Borrowed primary key type for StoredEpochEncryptionKeypair
Fields
conversation_id: &'a ConversationIdRefown_leaf_idx: u32epoch: u64Implementations
Sourceimpl<'a> StoredEpochEncryptionKeypairPkRef<'a>
impl<'a> StoredEpochEncryptionKeypairPkRef<'a>
Sourcepub fn parse_bytes(bytes: &'a [u8]) -> CryptoKeystoreResult<Self>
pub fn parse_bytes(bytes: &'a [u8]) -> CryptoKeystoreResult<Self>
Parse this PK from its binary representation
OpenMLS assumes that all primary keys are byte slices, and designed its trait structure accordingly. So we have to be able to parse a (probably-freshly-constructed) slice into a discrete type.