pub struct StoredHpkePrivateKey {
pub sk: Vec<u8>,
pub pk: Vec<u8>,
}Expand description
Entity representing a persisted HpkePrivateKey (related to LeafNode Private keys that the client is aware of)
Fields
sk: Vec<u8>pk: Vec<u8>Trait Implementations
Sourceimpl BorrowPrimaryKey for StoredHpkePrivateKey
impl BorrowPrimaryKey for StoredHpkePrivateKey
type BorrowedPrimaryKey = [u8]
Sourcefn borrow_primary_key(&self) -> &Self::BorrowedPrimaryKey
fn borrow_primary_key(&self) -> &Self::BorrowedPrimaryKey
Borrow this entity’s primary key without copying any data. Read more
Sourceimpl Clone for StoredHpkePrivateKey
impl Clone for StoredHpkePrivateKey
Sourcefn clone(&self) -> StoredHpkePrivateKey
fn clone(&self) -> StoredHpkePrivateKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoredHpkePrivateKey
impl Debug for StoredHpkePrivateKey
Sourceimpl<'de> Deserialize<'de> for StoredHpkePrivateKey
impl<'de> Deserialize<'de> for StoredHpkePrivateKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Entity for StoredHpkePrivateKey
impl Entity for StoredHpkePrivateKey
Sourceconst COLLECTION_NAME: &'static str = "mls_hpke_private_keys"
const COLLECTION_NAME: &'static str = "mls_hpke_private_keys"
The table name for this entity
Sourcefn get(conn: &Connection, key: &Vec<u8>) -> CryptoKeystoreResult<Option<Self>>
fn get(conn: &Connection, key: &Vec<u8>) -> CryptoKeystoreResult<Option<Self>>
Get an entity by its primary key. Read more
Sourcefn count(conn: &Connection) -> CryptoKeystoreResult<u32>
fn count(conn: &Connection) -> CryptoKeystoreResult<u32>
Count the number of entities of this type in the database.
Sourcefn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
fn load_all(conn: &Connection) -> CryptoKeystoreResult<Vec<Self>>
Retrieve all entities of this type from the database.
Sourceimpl EntityDatabaseMutation for StoredHpkePrivateKey
impl EntityDatabaseMutation for StoredHpkePrivateKey
Sourcetype AutoGeneratedFields = ()
type AutoGeneratedFields = ()
The
pre_save method might generate or update some fields of the item. The canonical example is an updated_at
field. Read moreSourcefn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
fn save(&self, tx: &Transaction<'_>) -> CryptoKeystoreResult<()>
Use the transaction’s interface to save this entity to the database
Sourcefn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
fn count(tx: &Transaction<'_>) -> CryptoKeystoreResult<u32>
Use the transaction’s interface to count the number of entities of this type in the database.
Sourcefn delete(tx: &Transaction<'_>, id: &Vec<u8>) -> CryptoKeystoreResult<bool>
fn delete(tx: &Transaction<'_>, id: &Vec<u8>) -> CryptoKeystoreResult<bool>
Use the transaction’s inteface to delete this entity from the database. Read more
Sourcefn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
fn pre_save(&mut self) -> CryptoKeystoreResult<Self::AutoGeneratedFields>
Adjust self before saving. Read more
Sourceimpl EntityDeleteBorrowed for StoredHpkePrivateKey
impl EntityDeleteBorrowed for StoredHpkePrivateKey
Sourcefn delete_borrowed(
tx: &Transaction<'_>,
id: &[u8],
) -> CryptoKeystoreResult<bool>
fn delete_borrowed( tx: &Transaction<'_>, id: &[u8], ) -> CryptoKeystoreResult<bool>
Delete an entity by a borrowed form of its primary key.
Sourceimpl EntityGetBorrowed for StoredHpkePrivateKey
impl EntityGetBorrowed for StoredHpkePrivateKey
Sourcefn get_borrowed(
conn: &Connection,
key: &[u8],
) -> CryptoKeystoreResult<Option<Self>>
fn get_borrowed( conn: &Connection, key: &[u8], ) -> CryptoKeystoreResult<Option<Self>>
Get an entity by a borrowed form of its primary key.
Sourceimpl PartialEq for StoredHpkePrivateKey
impl PartialEq for StoredHpkePrivateKey
Sourcefn eq(&self, other: &StoredHpkePrivateKey) -> bool
fn eq(&self, other: &StoredHpkePrivateKey) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PrimaryKey for StoredHpkePrivateKey
impl PrimaryKey for StoredHpkePrivateKey
Sourceimpl Serialize for StoredHpkePrivateKey
impl Serialize for StoredHpkePrivateKey
Sourceimpl ToValue for StoredHpkePrivateKey
impl ToValue for StoredHpkePrivateKey
Sourceimpl Zeroize for StoredHpkePrivateKey
impl Zeroize for StoredHpkePrivateKey
impl Eq for StoredHpkePrivateKey
impl StructuralPartialEq for StoredHpkePrivateKey