pub struct UniqueArc<T> { /* private fields */ }Expand description
A smart pointer which has exactly one strong reference to the inner type, but may have several weak references.
This type is intentionally !Clone so that we know for a fact that it can be
safely unpacked.
Implementations
Sourceimpl UniqueArc<Transaction>
impl UniqueArc<Transaction>
Sourcepub async fn commit(self) -> Result<(), CryptoKeystoreError>
pub async fn commit(self) -> Result<(), CryptoKeystoreError>
Persists all the operations in the database.
Sourcepub async fn rollback(self) -> CryptoKeystoreResult<()>
pub async fn rollback(self) -> CryptoKeystoreResult<()>
Roll back this transaction in the database.
There are two differences between manual rollback and implicit:
- manual rollback clears the database’s weak transaction ref
- manual rollback permits propagation of db-level errors
Sourceimpl<T> UniqueArc<T>
impl<T> UniqueArc<T>
Sourcepub async fn into_inner(this: Self) -> T
pub async fn into_inner(this: Self) -> T
Unpack this UniqueArc, returning the inner value.
This waits for any in-flight UniqueWeak::upgrade / UniqueWeak::upgrade_sync
guard to drop before unpacking, so that the sole remaining strong reference is the one
held by this UniqueArc.