pub struct UniqueArc<T> { /* private fields */ }Expand description
A smart pointer which has exactly one strong reference to the inner type, but may have several weak references.
This type is intentionally !Clone so that we know for a fact that it can be
safely unpacked.
Implementations
Sourceimpl UniqueArc<Transaction>
impl UniqueArc<Transaction>
Sourcepub async fn commit(self) -> Result<(), CryptoKeystoreError>
pub async fn commit(self) -> Result<(), CryptoKeystoreError>
Persists all the operations in the database. It will effectively open a transaction internally, perform all the buffered operations and commit.
Sourceimpl<T> UniqueArc<T>
impl<T> UniqueArc<T>
Sourcepub async fn into_inner(this: Self) -> T
pub async fn into_inner(this: Self) -> T
Unpack this UniqueArc, returning the inner value.
This waits for any in-flight UniqueWeak::upgrade / UniqueWeak::upgrade_sync
guard to drop before unpacking, so that the sole remaining strong reference is the one
held by this UniqueArc.