pub trait UnifiedEntityDeleteBorrowed: UnifiedEntityDatabaseMutation + BorrowPrimaryKey {
// Required method
fn delete_borrowed(
tx: &Transaction<'_>,
id: &Self::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<bool>
where for<'pk> &'pk Self::BorrowedPrimaryKey: KeyType;
}Expand description
Extend an Entity with db-mutating operations which can be performed when provided with a transaction.
Required Methods
Sourcefn delete_borrowed(
tx: &Transaction<'_>,
id: &Self::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<bool>where
for<'pk> &'pk Self::BorrowedPrimaryKey: KeyType,
fn delete_borrowed(
tx: &Transaction<'_>,
id: &Self::BorrowedPrimaryKey,
) -> CryptoKeystoreResult<bool>where
for<'pk> &'pk Self::BorrowedPrimaryKey: KeyType,
Delete an entity by a borrowed form of its primary key.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.